
function q=min_integral(f,I,n,k)
% min_integral - beräknar integralen av f(x) på intervallet I.
%
%   Syntax:
%           q =  min_integral(f,I,n,k)
%   Argument:
%           f - funktionshandtag: pekar på namnet till en funktionsfil eller
%               till en anonym funktion. T.ex. f=@funk eller f = @(x)sin(x.^2)
%           I - 1x2 matris, anger ett intervall I=[a b]
%           n - positivt heltal, anger antalet delintervall.
%           k - anger val av metod, se nedan.
%   Returnerar:
%           q - ett tal, ger approximationen av integralen.
%   Beskrivning:
%           Programmet beräknar ett approximativt värde på integralen
%           av f(x) över intervallet I med antingen rektangelmetoden vänster (k=1),
%           rektangelmetoden höger (k=2), mittpunktsmetoden (k=3) eller 
%           trapetsmetoden (k=4).
%   Exempel:
%           q = min_integral(@(x)x.*sin(x),[0 1],100,2)

    a=I(1);
    b=I(2);
    h=(b-a)/n;

    ...

